@@ -57,7 +57,7 @@ class NotSupportedError(DatabaseError): pass
 
 
 class Connection(object):
-    def __init__(self, read: callable, write: callable=None, read_more: callable=None):
+    def __init__(self, read: callable, write: callable=None, read_more: callable=None, flavor: str=None):
         """
         Create a DBI-compatible adapter that uses the supplied functions.
         :param read:        A method with two arguments: sql and parameters.  Returns cols, rows, more.  Cols will be
@@ -65,10 +65,13 @@ class Connection(object):
             rows, or else a hint to read_more() for the next page.
         :param write:       A method with two arguments: sql and parameters.
         :param read_more:   A method with one argument: 'more'.  Returns cols, rows, more, (same as read()).
+        :param flavor:      Type of database being emulated/proxied.  'mysql', 'postgres', 'bigquery', etc. - see also
+                            db_conn_flavor().
         """
         self.read = read
         self.read_more = read_more
         self.write = write
+        self._flavor = flavor
 
     def __enter__(self):
         return self
